Learn R Programming

citbcmst (version 1.0.4)

cit.assignBcmst: cit.assignBcmst

Description

assign expression data sample(s) to CIT Breast Cancer Molecular Subtypes

Usage

cit.assignBcmst( data, data.annot, data.colId="Probe.Set.ID", data.colMap=c("Probe.Set.ID","Gene.Symbol","Ensembl","UniGene.ID")[1], citbcmst.annot=NULL,citbcmst.colId="Probe.Set.ID", citbcmst.colMap=c("Probe.Set.ID","Gene.Symbol","Ensembl","UniGene.ID")[1], dist.method="dlda", dist.difftopcentcutoff=NULL, dist.disttocentcutoff=NULL, dist.maxcutoff=NULL, plot=FALSE)

Arguments

data
a data.frame of expression data with id as rownames
data.annot
a data.frame of data probes annotations
data.colId
name of the column in data.annot containing data probes id
data.colMap
name of the column in data.annot containing data probes names to map
citbcmst.annot
affymetrix annotation data.frame, if NULL (default) takes the embeded annotation in object citbcmst$data.annot
citbcmst.colId
name of the column in citbcmst.annot corresponding to rownames of citbcmst$data. Default "Probe.Set.ID"
citbcmst.colMap
name of the column in citbcmst.annot containing the same annotation as in data.colMap
dist.method
metric to compute distance to assign a sample to a subtype. Default for Affymetrix data "dlda". For other platforms "pearson".
dist.difftopcentcutoff
cut-off on the differences between distances to centroids. If the distance is inferior to this cut-off for n centroids the sample is assigned to the n subtypes in the output variable citbcmst.mixed. If NULL, the cut-off is defined as the 1st decile of the difference between the top 2 closest centroids on data used to compute centroids.
dist.disttocentcutoff
cut-off on the mad (median absolute deviation) of distances to the centroid to define a sample as outlier. If the distance to the centroid of the assigned subtype is superior to sdisttocent*mad(distances of centroids samples to this centroid)
dist.maxcutoff
samples for which nearest centroid is above this threshold are discarted (used only if dis.meth = "pearson" or "spearman")
plot
if TRUE plot an acp of citdata used to classify, and of the input data with subtype affectation and dist to centroid class

Value

Examples

Run this code
# load exp.norm.bertheau07 object stored in /inst/extdata
exp.annot.bertheau07 <- data.frame(id=rownames(exp.norm.bertheau07), stringsAsFactors=FALSE,
row.names=rownames(exp.norm.bertheau07) )
citbcmst.bertheau07 <- cit.assignBcmst(    data=exp.norm.bertheau07,
                                           data.annot=exp.annot.bertheau07,
                                           data.colId="id",
                                           data.colMap="id" ,
                                           citbcmst.colMap="Probe.Set.ID",
                                           dist.method="dlda",
                                           plot=TRUE
                                 ) 

Run the code above in your browser using DataLab