Learn R Programming

citbcmst (version 1.0.4)

exp.norm.chanrion08: Non Affymetrix Breast Cancer Expression dataset from Chanrion et al 2008

Description

Normalized expression data of 155 samples from a ER+ cohort for Tamoxifen response study, reduced to the 68 genes (originally 4397 70-mer oligonucleotides), hybridised on Qiagen/Operon oligonucleotide microarrays

Usage

exp.norm.chanrion08

Arguments

Format

A data.frame of normalized expression data of 155 samples, reduced to 68 probes with gene symbol as rownames

GEO GSE_9393

References

Chanrion M, Negre V, Fontaine H, Salvetat N, Bibeau F, et al. (2008). A gene expression signature that can predict the recurrence of tamoxifen-treated primary breast cancer. Clin Cancer Res, 14: 1744-1752.